Type: Package
Package: sprtt
Title: Sequential Probability Ratio Tests Toolbox
Version: 0.3.1
Date: 2026-04-13
Authors@R: 
    c(person(given = "Meike",
             family = "Snijder-Steinhilber",
             role = c("aut", "cre"),
             email = "Meike.Steinhilber@aol.com",
             comment = c(ORCID = "0000-0002-7144-2100")),
      person(given = "Martin",
             family = "Schnuerch",
             role = c("aut", "ths"),
             comment = c(ORCID = "0000-0001-6531-2265")),
      person(given = "Anna-Lena",
             family = "Schubert",
             role = c("aut", "ths"),
             comment = c(ORCID = "0000-0001-7248-0662"))
      )
Maintainer: Meike Snijder-Steinhilber <Meike.Steinhilber@aol.com>
Description: A toolbox for Sequential Probability Ratio Tests (SPRT) based on
    Wald (1945) <doi:10.2134/agronj1947.00021962003900070011x>.
    SPRTs are applied during the sampling process, ideally after each
    observation, and at every stage return a decision to either continue
    sampling or terminate and accept one of the specified hypotheses.
    The `seq_ttest()` function performs one-sample, two-sample, and paired
    t-tests for one- and two-sided hypotheses (Schnuerch & Erdfelder (2019)
    <doi:10.1037/met0000234>). The `seq_anova()` function performs a sequential
    one-way fixed effects ANOVA (Steinhilber et al. (2024)
    <doi:10.1037/met0000677>). The `plan_sample_size()` function helps plan
    sequential studies by simulating required sample sizes across a range of
    effect sizes. For more information, see the vignettes
    browseVignettes(package = "sprtt") or the package website
    <https://meikesteinhilber.github.io/sprtt/>.
License: AGPL (>= 3)
URL: https://meikesteinhilber.github.io/sprtt/
BugReports: https://github.com/MeikeSteinhilber/sprtt/issues
Depends: R (>= 3.5.0)
Imports: rappdirs, methods, stats, dplyr, MBESS, purrr, glue, ggplot2,
        lifecycle, knitr, rmarkdown, gt, ggtext, scales, piggyback
Suggests: testthat (>= 3.0.0), testthis, withr, xml2, effsize,
        effectsize, vdiffr, diffviewer
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
LazyData: yes
LazyDataCompression: xz
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-06 11:58:02 UTC; msteinhi
Author: Meike Snijder-Steinhilber [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7144-2100>),
  Martin Schnuerch [aut, ths] (ORCID:
    <https://orcid.org/0000-0001-6531-2265>),
  Anna-Lena Schubert [aut, ths] (ORCID:
    <https://orcid.org/0000-0001-7248-0662>)
Repository: CRAN
Date/Publication: 2026-05-06 12:20:02 UTC
Built: R 4.6.0; ; 2026-05-06 16:44:06 UTC; unix
