# Generated by roxygen2: do not edit by hand

export(cache_clear)
export(cache_info)
export(download_sample_size_data)
export(draw_sample_mixture)
export(draw_sample_normal)
export(load_sample_size_data)
export(plan_sample_size)
export(plot_anova)
export(seq_anova)
export(seq_ttest)
exportMethods("[")
import(dplyr)
import(ggplot2)
import(glue)
import(gt)
import(purrr)
importFrom(MBESS,conf.limits.ncf)
importFrom(ggtext,element_markdown)
importFrom(glue,glue)
importFrom(knitr,opts_chunk)
importFrom(lifecycle,deprecated)
importFrom(methods,callNextMethod)
importFrom(methods,new)
importFrom(methods,validObject)
importFrom(scales,percent)
importFrom(scales,percent_format)
importFrom(stats,as.formula)
importFrom(stats,df)
importFrom(stats,dt)
importFrom(stats,model.frame)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,t.test)
