#' Test data to run the examples
#'
#'A dataset that includes 120 individuals with sex gender and monthly income.
#'
#' @format  A data frame with 2 variables:
#' \describe{
#'   \item{monthly_income}{ }
# #'   \item{in_debt}{0 = no and 1 = yes}
#'   \item{sex}{ }
# #'   \item{age}{ }
#' }
"df_income"


#' Test data to run the examples
#'
#'A dataset that includes 120 individuals.
#'
#' @format  A data frame with 2 variables:
#' \describe{
#'   \item{baseline_stress}{ }
#'   \item{one_year_stress}{ }
#' }
"df_stress"

#' Test data to run the examples
#'
#'A dataset that includes 120 individuals.
#'
#' @format  A data frame with 2 variables:
#' \describe{
#'   \item{treatment_group}{ }
#'   \item{control_group}{ }
#' }
"df_cancer"
