#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom lifecycle deprecated
## usethis namespace: end
NULL

#' sprtt: help page.
#'
#' This package provides the implementation of sequential probability
#' ratio tests using t-statistic.
#'
#' @section detailed help pages:
#' For detailed instructions on the `sprtt` package, see:
#' `vignette("sprtt")` or https://meikesteinhilber.github.io/sprtt/"
#'
#' @section sprtt functions:
#' * [`seq_ttest`] Performs one and two sample sequential t-tests on vectors of
#' data.
#' * [`seq_anova`] Performs a sequential one-way ANOVA on vectors of
#' data.
#'
#' @docType package
#' @name sprtt
#'



