# calc_likelihoods_anova: Check warnings & messages

    Code
      calc_likelihoods_anova(seq_anova_arguments, non_centrality_parameter,
        F_statistic)
    Output
      $likelihood_1
      [1] 0.05244313
      
      $likelihood_0
      [1] 4.794529e-09
      
      $ratio
      [1] 10938119
      
      $likelihood_1_log
      [1] -2.948026
      
      $likelihood_0_log
      [1] -19.15579
      
      $ratio_log
      [1] 16.20776
      

