# calc_non_centrality_parameter

    Code
      show(calc_non_centrality_parameter_ttest(seq_ttest_arguments))
    Output
      [1] 1.788854

---

    Code
      show(calc_non_centrality_parameter_anova(seq_anova_arguments))
    Output
      [1] 32

