% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/load_data_external.R
\name{cache_clear}
\alias{cache_clear}
\title{Clear cached simulation data}
\usage{
cache_clear()
}
\value{
Invisibly returns \code{TRUE} if cache was cleared, \code{FALSE} if no cache existed.
}
\description{
\ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#experimental}{\figure{lifecycle-experimental.svg}{options: alt='[Experimental]'}}}{\strong{[Experimental]}}

Removes locally cached simulation data (~150 MB) used by \code{\link[=plan_sample_size]{plan_sample_size()}}.
Data will be automatically re-downloaded on next use of sample size planning functions.

This function is useful when:
\itemize{
\item You want to free up disk space
\item The cached data may be outdated and you want to force a fresh download
\item Troubleshooting cache-related issues
}
}
\examples{
\dontrun{
# Clear cache
cache_clear()
}
}
